@@ -17,7 +17,7 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **
-** @(#)$Id: hash_int.h,v 1.5 2000/01/27 03:48:55 klmitch Exp $
+** @(#)$Id: hash_int.h,v 1.6 2000/08/02 19:34:02 klmitch Exp $
 */
 #ifndef __include_hash_int_h__
 #define __include_hash_int_h__
@@ -39,4 +39,7 @@ _h_ul _hash_compare(hash_tab *table, hash_key *key1, hash_key *key2);
 #define _hash_rollover(mod)	(((mod) * 4) / 3)
 #define _hash_rollunder(mod)	(((mod) * 3) / 4)
 
+#define HASH_FLAGS_FREEZE	0x0001	/* hash table frozen */
+#define HASH_FLAGS_RESIZE	0x0002	/* hash table needs resizing */
+
 #endif /* __include_hash_int_h__ */
